## House prices

### Description

A dataset containing the prices and other attributes of 128 recent sales of single-family houses in Springfield. The variables are as follows:

### Variables

- price = price at which the house was eventually sold in US dollars ($345,500--$1,056,000)
- squarefeet = floor area in square feet (1450--2590)
- bedrooms = number of bedrooms (2, 3, 4, or 5)
- bathrooms = number of bathrooms (2, 3, or 4)
- brick = whether the construction is primarily brick or not (Yes or No)
- neighborhood = one of the three neighborhoods in Springfield (East, West or North)